@@ -117,8 +117,8 @@ plot.funData <- function(x, y, obs = 1:nObs(x), type = "l", lty = 1, lwd = 1,
     
     if(plotNA) # interpolate NA values
     {
-        plot(approxNA(x), obs = obs, type = "l", lty = lty,  lwd = lwd, col = col, xlab = xlab, ylab = ylab, add = add, ...)
-        add = TRUE
+      plot(approxNA(x), obs = obs, type = "l", lty = lty,  lwd = lwd, col = col, xlab = xlab, ylab = ylab, add = add, ...)
+      add = TRUE
     }
     
     graphics::matplot(x = x@argvals[[1]], y = t(x@X[obs,, drop = FALSE]), type = type, lty = lty,  lwd = lwd, col = col, xlab = xlab, ylab = ylab, add = add, ...)
@@ -231,9 +231,9 @@ plot.multiFunData <- function(x, y, obs = 1:nObs(x), dim = 1:length(x), par.plot
     stop("Parameter 'par.plot' must be either NULL or passed as a list.")
   
   if(!any(is.null(main), length(main) == c(1,length(x))))
-      stop("Parameter 'main' must be either NULL or have lengths 1 or ", length(x), ".")
+    stop("Parameter 'main' must be either NULL or have lengths 1 or ", length(x), ".")
   if(length(main) == 1)
-        main <- rep(main, length(dim))
+    main <- rep(main, length(dim))
   
   if(length(xlab) == 1)
     xlab <- rep(xlab, length(dim))
@@ -254,8 +254,8 @@ plot.multiFunData <- function(x, y, obs = 1:nObs(x), dim = 1:length(x), par.plot
         stop("The ylim argument must be either a vector (used for all elements) or a list with values for each element.")
     }  
   }
-
-
+  
+  
   # if no par.plot specified: get graphics parameters
   if(is.null(par.plot))
   {
@@ -268,14 +268,14 @@ plot.multiFunData <- function(x, y, obs = 1:nObs(x), dim = 1:length(x), par.plot
   # split screen
   par(mfrow = c(1,length(dim)))
   
-    # plot the univariate functions
+  # plot the univariate functions
   for(i in 1:length(dim))
     plot(x[[dim[i]]], obs = obs, main = main[i], xlab = xlab[i], ylab = ylab[i], log = log[i], ylim = ylim[[i]], ...)
   
   # if no par.plot specified: reset graphics parameters
   if(is.null(par.plot))
     par(oldPar)
-
+  
   # return invisibly
   invisible()
 }
@@ -387,17 +387,15 @@ setMethod("plot", signature = signature(x = "irregFunData", y = "missing"),
 #' \code{\link[zoo]{zoo}} and is currently implemented for one-dimensional 
 #' functions only in the function \code{\link{approxNA}}.
 #' 
-#' @param data A \code{funData} object on a one- or two-dimensional domain.
+#' @param object A \code{funData} object on a one- or two-dimensional domain.
 #' @param obs A vector of numerics giving the observations to plot. Defaults to 
-#'   all observations in \code{data}. For two-dimensional functions (images) 
+#'   all observations in \code{object}. For two-dimensional functions (images) 
 #'   \code{obs} must have length 1.
 #' @param geom A character string describing the geometric object to use.
 #'   Defaults to \code{"line"}. See \pkg{ggplot2} for details.
 #' @param plotNA Logical. If \code{TRUE}, missing values are interpolated using 
 #'   the \code{\link{approxNA}} function (only for one-dimensional functions). 
 #'   Defaults to \code{FALSE}. See Details.
-#' @param add Logical. If \code{TRUE}, add to current plot (only for 
-#'   one-dimensional functions). Defaults to \code{FALSE}.
 #' @param ... Further parameters passed to \code{\link[ggplot2]{geom_line}} (for
 #'   one dimensional domains, e.g. \code{alpha, color, fill, linetype, size}) or
 #'   to \code{\link[ggplot2]{geom_raster}} (for two-dimensional domains, e.g.
@@ -409,20 +407,22 @@ setMethod("plot", signature = signature(x = "irregFunData", y = "missing"),
 #' @seealso \code{\linkS4class{funData}}, \code{\link[ggplot2]{ggplot}}, 
 #'   \code{\link{plot.funData}}
 #'   
+#' @export autoplot.funData
+#'   
 #' @examples
-#' # Install package ggplot2 before running the examples
-#' \dontshow{requireNamespace("ggplot2", quietly = TRUE)}
+#' # Install / load package ggplot2 before running the examples
+#' library("ggplot2")
 #' 
 #' # One-dimensional
 #' argvals <- seq(0,2*pi,0.01)
 #' object <- funData(argvals,
 #'                    outer(seq(0.75, 1.25, length.out = 11), sin(argvals)))
 #' 
-#' g <- ggplot(object) # returns ggplot object
+#' g <- autoplot(object) # returns ggplot object
 #' g # plot the object
 #' 
 #' # add the mean function in red
-#' g + ggplot(meanFunction(object), add = TRUE, col = 2)
+#' g + autolayer(meanFunction(object),  col = 2)
 #' 
 #' # Two-dimensional
 #' X <- array(0, dim = c(2, length(argvals), length(argvals)))
@@ -431,9 +431,9 @@ setMethod("plot", signature = signature(x = "irregFunData", y = "missing"),
 #' object2D <- funData(list(argvals, argvals), X)
 #' 
 #' \donttest{
-#' ggplot(object2D, obs = 1)
-#' ggplot(object2D, obs = 2)}
-#' \dontrun{plot(object2D)} # must specify obs!
+#' autoplot(object2D, obs = 1)
+#' autoplot(object2D, obs = 2)}
+#' \dontrun{autoplot(object2D)} # must specify obs!
 #' 
 #' ### More examples ###
 #' \donttest{
@@ -443,78 +443,85 @@ setMethod("plot", signature = signature(x = "irregFunData", y = "missing"),
 #' \dontshow{requireNamespace("zoo", quietly = TRUE)}
 #' \dontshow{requireNamespace("gridExtra", quietly = TRUE)}
 #' objectMissing <- funData(1:5, rbind(c(1, NA, 5, 4, 3), c(10, 9, NA, NA, 6)))
-#' g1 <- ggplot(objectMissing) # the default
-#' g2 <- ggplot(objectMissing, plotNA = TRUE) # requires zoo
+#' g1 <- autoplot(objectMissing) # the default
+#' g2 <- autoplot(objectMissing, plotNA = TRUE) # requires zoo
 #' 
-#' gridExtra::grid.arrange(g1 + ggplot2::ggtitle("plotNA = FALSE (default)"),
-#'                         g2 + ggplot2::ggtitle("plotNA = TRUE")) # requires gridExtra
+#' gridExtra::grid.arrange(g1 + ggtitle("plotNA = FALSE (default)"),
+#'                         g2 + ggtitle("plotNA = TRUE")) # requires gridExtra
 #' 
 #' # Customizing plots (see ggplot2 documentation for more details)
 #' # parameters passed to geom_line are passed via the ... argument
-#' gFancy <- ggplot(object, color = "red", linetype = 2) 
+#' gFancy <- autoplot(object, color = "red", linetype = 2) 
 #' gFancy
 #' 
 #' # new layers can be added directly to the ggplot object
-#' gFancy + ggplot2::theme_bw() # add new layers to the ggplot object
-#' gFancy + ggplot2::ggtitle("Fancy Plot with Title and Axis Legends") + 
-#'          ggplot2::xlab("The x-Axis") + ggplot2::ylab("The y-Axis")
+#' gFancy + theme_bw() # add new layers to the ggplot object
+#' gFancy + ggtitle("Fancy Plot with Title and Axis Legends") + 
+#'          xlab("The x-Axis") + ylab("The y-Axis")
 #' 
-#' ggplot(object2D, obs = 1) + ggplot2::ggtitle("Customized 2D plot") + ggplot2::theme_minimal() +
-#'           ggplot2::scale_fill_gradient(high = "green", low = "blue", name = "Legend here")
+#' autoplot(object2D, obs = 1) + ggtitle("Customized 2D plot") + theme_minimal() +
+#'           scale_fill_gradient(high = "green", low = "blue", name = "Legend here")
 #' }
-ggplot.funData <- function(data, obs = 1:nObs(data), geom = "line", plotNA = FALSE, add = FALSE, ...)
+autoplot.funData <- function(object, obs = 1:nObs(object), geom = "line", plotNA = FALSE, ...)
 {
-  if(!(requireNamespace("ggplot2", quietly = TRUE) & requireNamespace("reshape2", quietly = TRUE)))
+  if(!(requireNamespace("ggplot2", quietly = TRUE)))
   {
-    warning("Please install the ggplot2 and reshape2 packages to use the ggplot function for funDataObjects.")
+    warning("Please install the ggplot2 package to use the autoplot function for funData objects.")
     return()
   } 
   
-  if(dimSupp(data) > 2)
-    stop("ggplot is implemented only for functional data with one- or two-dimensional domain")
+  if(dimSupp(object) > 2)
+    stop("autoplot is implemented only for functional data with one- or two-dimensional domain")
   
-  if(! all(is.numeric(obs), 0 < obs, obs <= nObs(data)))
-    stop("Parameter 'obs' must be a vector of numerics with values between 1 and ", nObs(data), ".")
+  if(! all(is.numeric(obs), 0 < obs, obs <= nObs(object)))
+    stop("Parameter 'obs' must be a vector of numerics with values between 1 and ", nObs(object), ".")
   if(! all(is.logical(plotNA), length(plotNA) == 1))
     stop("Parameter 'plotNA' must be passed as a logical.")
-  if(! all(is.logical(add), length(add) == 1))
-    stop("Parameter 'add' must be passed as a logical.")
+  if(dimSupp(object) == 2 & length(obs) > 1)
+    stop("Specify one observation for plotting")
   
-  if(dimSupp(data) == 1)
-  {
-    if(plotNA) # interpolate NA values
-        data <- approxNA(data)
+  if(dimSupp(object) == 1 & plotNA) # interpolate NA values
+    object <- approxNA(object)
+  
+  meltData <- as.data.frame(extractObs(object, obs))
+  
+  if(dimSupp(object) == 1)
+    p <- ggplot2::ggplot(data = meltData, ggplot2::aes_string(x = "argvals1", y = "X", group = "obs")) +
+    ggplot2::stat_identity(geom = geom, ...) + 
+    ggplot2::ylab("") 
+  if(dimSupp(object) == 2)
+    p <- ggplot2::ggplot(meltData, ggplot2::aes_string(x = "argvals1", y = "argvals2")) + 
+    ggplot2::geom_raster(ggplot2::aes_string(fill = "X"), ...) + 
+    ggplot2::xlab("") + ggplot2::ylab("") + ggplot2::labs(fill = "")
+  
+  return(p)
+}
 
-    meltData <- reshape2::melt(data@X[obs, , drop = FALSE], varnames = c("obsInd", "obsPointX"))
-    meltData$argvals <- data@argvals[[1]][meltData$obsPointX]
-    meltData$obsInd <- as.factor(meltData$obsInd)
-    
-    if(add == TRUE)
-      p <- ggplot2::stat_identity(data = meltData, ggplot2::aes_string(x = "argvals", y = "value", group = "obsInd"),
-                             geom = geom, ...)
-    else
-      p <- ggplot2::ggplot(data = meltData, ggplot2::aes_string(x = "argvals", y = "value", group = "obsInd")) +
-      ggplot2::stat_identity(geom = geom, ...) + 
-      ggplot2::ylab("") 
-  }
-  
-  if(dimSupp(data) == 2)
+#' @rdname autoplot.funData
+#' @export autolayer.funData
+autolayer.funData <- function(object, obs = 1:nObs(object), geom = "line", plotNA = FALSE, ...)
+{
+  if(!(requireNamespace("ggplot2", quietly = TRUE)))
   {
-    if(length(obs) > 1)
-      stop("Specify one observation for plotting")
-    
-    if(add == TRUE)
-      stop("Option add = TRUE not implemented for images")
-    
-    meltData <- reshape2::melt(data@X[obs, , , drop = FALSE], varnames = c("obsInd", "obsPointX", "obsPointY"))
-    meltData$argvalsX <- data@argvals[[1]][meltData$obsPointX]
-    meltData$argvalsY <- data@argvals[[2]][meltData$obsPointY]
-    meltData$obsInd <- as.factor(meltData$obsInd)
-    
-    p <- ggplot2::ggplot(meltData, ggplot2::aes_string(x = "argvalsX", y = "argvalsY")) + 
-      ggplot2::geom_raster(ggplot2::aes_string(fill = "value"), ...) + 
-      ggplot2::xlab("") + ggplot2::ylab("") + ggplot2::labs(fill = "")
-  }
+    warning("Please install the ggplot2 package to use the autolayer function for funData objects.")
+    return()
+  } 
+  
+  if(dimSupp(object) > 1)
+    stop("autolayer is implemented only for functional data with one-dimensional domain.")
+  
+  if(! all(is.numeric(obs), 0 < obs, obs <= nObs(object)))
+    stop("Parameter 'obs' must be a vector of numerics with values between 1 and ", nObs(object), ".")
+  if(! all(is.logical(plotNA), length(plotNA) == 1))
+    stop("Parameter 'plotNA' must be passed as a logical.")
+  
+  if(dimSupp(object) == 1 & plotNA) # interpolate NA values
+    object <- approxNA(object)
+  
+  meltData <- as.data.frame(extractObs(object, obs))
+  
+  p <- ggplot2::stat_identity(data = meltData, ggplot2::aes_string(x = "argvals1", y = "X", group = "obs"),
+                              geom = geom, ...)
   
   return(p)
 }
@@ -523,7 +530,7 @@ ggplot.funData <- function(data, obs = 1:nObs(data), geom = "line", plotNA = FAL
 #' Visualize multivariate functional data objects using ggplot
 #' 
 #' This function allows to plot \code{multiFunData} objects based on the \pkg{ggplot2} package. The 
-#' function applies the \code{\link{ggplot.funData}} function to each element and returns either a 
+#' function applies the \code{\link{autoplot.funData}} function to each element and returns either a 
 #' combined plot with all elements plotted in one row or a list containing the different subplots as
 #' \code{\link[ggplot2]{ggplot}} objects. The individual objects can be customized using all 
 #' functionalities of the \pkg{ggplot2} package.
@@ -531,16 +538,16 @@ ggplot.funData <- function(data, obs = 1:nObs(data), geom = "line", plotNA = FAL
 #' @section Warning: Currently, the function does not accept different parameters for the univariate
 #'   elements.
 #'   
-#' @param data A \code{multiFunData} object that is to be plotted.
+#' @param object A \code{multiFunData} object that is to be plotted.
 #' @param obs A vector of numerics giving the observations to plot. Defaults to all observations in 
-#'   \code{data}. For two-dimensional functions (images) \code{obs} must have length 1.
-#' @param dim The dimensions to plot. Defaults to \code{length(data)}, i.e. all functions in 
-#'   \code{data} are plotted.
+#'   \code{object}. For two-dimensional functions (images) \code{obs} must have length 1.
+#' @param dim The dimensions to plot. Defaults to \code{length(object)}, i.e. all functions in 
+#'   \code{object} are plotted.
 #' @param plotGrid Logical. If \code{TRUE}, the data is plotted using 
 #'   \code{\link[gridExtra]{grid.arrange}} and the list of \code{\link[ggplot2]{ggplot}} objects is 
 #'   returned invisibly. If \code{FALSE}, only the list of objects is returned. Defaults to 
 #'   \code{FALSE}.
-#' @param ... Further parameters passed to the univariate \code{\link{ggplot}} functions for 
+#' @param ... Further parameters passed to the univariate \code{\link{autoplot.funData}} functions for 
 #'   \code{funData} objects.
 #'   
 #' @return A list of \code{\link[ggplot2]{ggplot}} objects that are also printed directly as a grid 
@@ -549,9 +556,11 @@ ggplot.funData <- function(data, obs = 1:nObs(data), geom = "line", plotNA = FAL
 #' @seealso \code{\linkS4class{multiFunData}}, \code{\link[ggplot2]{ggplot}}, 
 #'   \code{\link{plot.multiFunData}}
 #'   
+#' @export autoplot.multiFunData
+#'   
 #' @examples
-#' # Install packages ggplot2 and gridExtra before running the examples
-#' \dontshow{requireNamespace("ggplot2", quietly = TRUE); requireNamespace("gridExtra", quietly = TRUE)}
+#' # Load packages ggplot2 and gridExtra before running the examples
+#' library("ggplot2"); library("gridExtra")
 #' 
 #' # One-dimensional elements
 #' argvals <- seq(0, 2*pi, 0.01)
@@ -560,12 +569,12 @@ ggplot.funData <- function(data, obs = 1:nObs(data), geom = "line", plotNA = FAL
 #' 
 #' m1 <- multiFunData(f1, f2)
 #' 
-#' g <- ggplot(m1) # default
+#' g <- autoplot(m1) # default
 #' g[[1]] # plot first element
 #' g[[2]] # plot second element
 #' gridExtra::grid.arrange(grobs = g, nrow = 1) # requires gridExtra package
 #' 
-#' ggplot(m1, plotGrid = TRUE) # the same directly with plotGrid = TRUE
+#' autoplot(m1, plotGrid = TRUE) # the same directly with plotGrid = TRUE
 #' 
 #' \donttest{
 #' # Mixed-dimensional elements
@@ -575,29 +584,30 @@ ggplot.funData <- function(data, obs = 1:nObs(data), geom = "line", plotNA = FAL
 #' 
 #' m2 <- multiFunData(f1, f2)
 #' 
-#' ggplot(m2, obs = 1, plotGrid = TRUE)
+#' autoplot(m2, obs = 1, plotGrid = TRUE)
 #' 
 #' # Customizing plots (see ggplot2 documentation for more details)
-#' g2 <- ggplot(m2, obs = 1)
-#' g2[[1]] <- g2[[1]] + ggplot2::ggtitle("First element") + ggplot2::theme_bw()
-#' g2[[2]] <- g2[[2]] + ggplot2::ggtitle("Second element") + 
-#'                      ggplot2::scale_fill_gradient(high = "green", low = "blue")
+#' g2 <- autoplot(m2, obs = 1)
+#' g2[[1]] <- g2[[1]] + ggtitle("First element") + theme_bw()
+#' g2[[2]] <- g2[[2]] + ggtitle("Second element") + 
+#'                      scale_fill_gradient(high = "green", low = "blue")
 #' gridExtra::grid.arrange(grobs = g2, nrow = 1) # requires gridExtra package
 #' }
-ggplot.multiFunData <- function(data, obs = 1:nObs(data), dim = 1:length(data), plotGrid = FALSE, ...)
+autoplot.multiFunData <- function(object, obs = 1:nObs(object), dim = 1:length(object), plotGrid = FALSE, ...)
 {
-  if(! all(is.numeric(dim), 0 < dim, dim <= length(data)))
-    stop("Parameter 'dim' must be a vector of numerics with values between 1 and ", length(data), ".")
+  if(! all(is.numeric(dim), 0 < dim, dim <= length(object)))
+    stop("Parameter 'dim' must be a vector of numerics with values between 1 and ", length(object), ".")
   if(! all(is.logical(plotGrid), length(plotGrid) == 1))
     stop("Parameter 'plotGrid' must be passed as a logical.")
   
-  p <- sapply(data[dim], ggplot.funData, obs = obs, ...,  simplify = FALSE)
+  # unlist(object) returns list of elements and [dim] subsets list of selected elements. This is NOT logical, but it works...
+  p <- sapply(unlist(object)[dim], autoplot.funData, obs = obs, ...,  simplify = FALSE)
   
   if(plotGrid)
   {
     if(!requireNamespace("gridExtra", quietly = TRUE))
     {
-      warning("Please install the gridExtra package to use the ggplot function for multiFunDataObjects with plotGrid = TRUE.")
+      warning("Please install the gridExtra package to use the autoplot function for multiFunDataObjects with plotGrid = TRUE.")
       return()
     } 
     
@@ -612,18 +622,16 @@ ggplot.multiFunData <- function(data, obs = 1:nObs(data), dim = 1:length(data),
 #' 
 #' This function allows to plot \code{irregFunData} objects on their domain
 #' based on the \pkg{ggplot2} package. The function provides a wrapper that
-#' rearranges the data in a \code{irregFunData} object returns a basic
+#'  returns a basic
 #' \code{\link[ggplot2]{ggplot}} object, which can be customized using all
 #' functionalities of the \pkg{ggplot2} package.
 #' 
-#' @param data A \code{irregFunData} object.
+#' @param object A \code{irregFunData} object.
 #' @param obs A vector of numerics giving the observations to plot. Defaults to
-#'   all observations in \code{data}. For two-dimensional functions (images)
+#'   all observations in \code{object}. For two-dimensional functions (images)
 #'   \code{obs} must have length 1.
 #' @param geom A character string describing the geometric object to use.
 #'   Defaults to \code{"line"}. See \pkg{ggplot2} for details.
-#' @param add Logical. If \code{TRUE}, add to current plot (only for 
-#'   one-dimensional functions). Defaults to \code{FALSE}.
 #' @param ... Further parameters passed to \code{\link[ggplot2]{stat_identity}},
 #'   e.g. \code{alpha, color, fill, linetype, size}).
 #'   
@@ -633,9 +641,11 @@ ggplot.multiFunData <- function(data, obs = 1:nObs(data), dim = 1:length(data),
 #' @seealso \code{\linkS4class{irregFunData}}, \code{\link[ggplot2]{ggplot}}, 
 #'   \code{\link{plot.irregFunData}}
 #'   
+#' @export autoplot.irregFunData
+#'   
 #' @examples
-#' # Install packages ggplot2 and gridExtra before running the examples
-#' \dontshow{requireNamespace("ggplot2", quietly = TRUE)}
+#' # Install / load package ggplot2 before running the examples
+#' library("ggplot2")
 #' 
 #' # Generate data
 #' argvals <- seq(0,2*pi,0.01)
@@ -644,77 +654,122 @@ ggplot.multiFunData <- function(data, obs = 1:nObs(data), dim = 1:length(data),
 #'                   X = lapply(ind, function(i){sample(1:10,1) / 10 * argvals[i]^2}))
 #' 
 #' # Plot the data
-#' ggplot(object)
+#' autoplot(object)
 #' 
 #'  # Parameters passed to geom_line are passed via the ... argument
-#' ggplot(object, color = "red", linetype = 3)
+#' autoplot(object, color = "red", linetype = 3)
 #' 
 #' # Plot the data and add green dots for the 2nd function
-#' ggplot(object) + ggplot(object, obs = 2, geom = "point", color = "green", add = TRUE)
+#' autoplot(object) + autolayer(object, obs = 2, geom = "point", color = "green")
 #' 
 #' # New layers can be added directly to the ggplot object using functions from the ggplot2 package
-#' g <- ggplot(object)
-#' g + ggplot2::theme_bw() + ggplot2::ggtitle("Plot with minimal theme and axis labels") +
-#'     ggplot2::xlab("The x-Axis") + ggplot2::ylab("The y-Axis")
-ggplot.irregFunData <- function(data, obs = 1:nObs(data), geom = "line", add = FALSE, ...)
+#' g <- autoplot(object)
+#' g + theme_bw() + ggtitle("Plot with minimal theme and axis labels") +
+#'     xlab("The x-Axis") + ylab("The y-Axis")
+autoplot.irregFunData <- function(object, obs = 1:nObs(object), geom = "line", ...)
 {
-  if(!(requireNamespace("ggplot2", quietly = TRUE) & requireNamespace("reshape2", quietly = TRUE)))
+  if(!(requireNamespace("ggplot2", quietly = TRUE)))
   {
-    warning("Please install the ggplot2 and reshape2 packages to use the ggplot function for funDataObjects.")
+    warning("Please install the ggplot2 package to use the autopplot function for irregfunData objects.")
     return()
   } 
   
-  if(! all(is.numeric(obs), 0 < obs, obs <= nObs(data)))
-    stop("Parameter 'obs' must be a vector of numerics with values between 1 and ", nObs(data), ".")
-  if(! all(is.logical(add), length(add) == 1))
-    stop("Parameter 'add' must be passed as a logical.")
+  if(! all(is.numeric(obs), 0 < obs, obs <= nObs(object)))
+    stop("Parameter 'obs' must be a vector of numerics with values between 1 and ", nObs(object), ".")
   
-  meltData <- reshape2::melt(data@X[obs])
-  names(meltData)[2] <- "obsInd"
-  meltData$argvals <- unlist(data@argvals[obs])
-  meltData$obsInd <- as.factor(meltData$obsInd)
+  meltData <- as.data.frame(extractObs(object,obs))
   
-  if(add == TRUE)
-    p <- ggplot2::stat_identity(data = meltData, ggplot2::aes_string(x = "argvals", y = "value", group = "obsInd"),
-                           geom = geom, ...)
-  else
-  p <- ggplot2::ggplot(meltData, ggplot2::aes_string(x = "argvals", y = "value", group = "obsInd")) +
+    p <- ggplot2::ggplot(meltData, ggplot2::aes_string(x = "argvals", y = "X", group = "obs")) +
     ggplot2::stat_identity(geom = geom, ...) + 
     ggplot2::ylab("") 
   
   return(p)
 }
 
+#' @rdname autoplot.irregFunData
+#' @export autolayer.irregFunData
+autolayer.irregFunData <- function(object, obs = 1:nObs(object), geom = "line", ...)
+{
+  if(!(requireNamespace("ggplot2", quietly = TRUE)))
+  {
+    warning("Please install the ggplot2 package to use the autolayer function for irregfunData objects.")
+    return()
+  } 
+  
+  if(! all(is.numeric(obs), 0 < obs, obs <= nObs(object)))
+    stop("Parameter 'obs' must be a vector of numerics with values between 1 and ", nObs(object), ".")
+  
+  meltData <- as.data.frame(extractObs(object,obs))
+
+    p <- ggplot2::stat_identity(object = meltData, ggplot2::aes_string(x = "argvals", y = "X", group = "obs"),
+                                geom = geom, ...)
+  
+  return(p)
+}
+
+
+#### ggplot (deprecated) ####
+
 #' ggplot Graphics for Functional Data Objects
-#' 
-#' The \code{funData} allows to plot \code{funData}, \code{multiFunData} and \code{irregFunData} 
-#' objects via the \pkg{ggplot2} package. For Details, see the help pages of the class-specific plot
-#' functions (see below).
-#' 
-#' @param data A \code{funData}, \code{multiFunData} or \code{irregFunData} object.
+#'
+#' This function is deprecated. Use \code{\link{autoplot.funData}} /
+#' \code{\link{autolayer.funData}} for \code{funData} objects,
+#' \code{\link{autoplot.multiFunData}} for \code{multiFunData} objects and
+#' \code{\link{autoplot.irregFunData}} /
+#' \code{\link{autolayer.irregFunData}} for \code{irregFunData} objects
+#' instead.
+#'
+#' @param data A \code{funData}, \code{multiFunData} or
+#'   \code{irregFunData} object.
 #' @param ... Further parameters passed to the class-specific methods.
-#'   
-#' @return A \code{\link[ggplot2]{ggplot} object}
-#'   
-#' @seealso \code{\link{ggplot.funData}} for \code{funData} objects,
-#'   \code{\link{ggplot.multiFunData}} for \code{multiFunData} objects and
-#'   \code{\link{ggplot.irregFunData}} for \code{irregFunData} objects.
+#'
+#' @return A \code{\link[ggplot2]{ggplot}} object
+#'
+#' @seealso  \code{\link[ggplot2]{ggplot}},
+#'   \code{\link[ggplot2]{autoplot}}, \code{\link[ggplot2]{autolayer}}
+#'   from package \pkg{ggplot2}
 setGeneric("ggplot", function(data,...) {standardGeneric("ggplot")})
 
-#' @rdname ggplot.funData
-#'
+#' @rdname ggplot
+#' 
+#' @param add Logical. If \code{TRUE}, add to current plot (only for 
+#'   one-dimensional functions). Defaults to \code{FALSE}.
+#'   
 #' @exportMethod ggplot
 setMethod("ggplot", signature = signature(data = "funData"),
-          function(data,...){ggplot.funData(data,...)})
+          function(data, add = FALSE,...){
+            if(add == FALSE)
+            {
+              .Deprecated("autoplot", old = "ggplot")
+              return(autoplot.funData(data, ...))
+            } 
+            else
+            {
+              .Deprecated("autolayer", old = "ggplot")
+              return(autolayer.funData(data, ...))
+            }
+          })
 
-#' @rdname ggplot.multiFunData
-#'
+#' @rdname ggplot
 #' @exportMethod ggplot
 setMethod("ggplot", signature = signature(data = "multiFunData"),
-          function(data,...){ggplot.multiFunData(data,...)})
+          function(data, ...){
+            .Deprecated("autoplot", old = "ggplot")
+            return(autoplot.multiFunData(data, ...))
+          })
 
-#' @rdname ggplot.irregFunData
-#'
+#' @rdname ggplot
 #' @exportMethod ggplot
 setMethod("ggplot", signature = signature(data = "irregFunData"),
-          function(data,...){ggplot.irregFunData(data,...)})
\ No newline at end of file
+          function(data, add = FALSE,...){
+            if(add == FALSE)
+            {
+              .Deprecated("autoplot", old = "ggplot")
+              return(autoplot.irregFunData(data, ...))
+            } 
+            else
+            {
+              .Deprecated("autolayer", old = "ggplot")
+              return(autolayer.irregFunData(data, ...))
+            }
+          })
\ No newline at end of file
